#' timetk: Time Series Analysis in the Tidyverse
#'
#' The `timetk` package combines a collection of coercion tools for
#' time series analysis.
#'
#' @details
#' The `timetk` package has several benefits:
#'
#' 1. Visualizing Time Series
#' 2. Wrangling Time Series.
#' 3. Preprocessing and Feature Engineering.
#'
#' To learn more about `timetk`, start with the documentation:
#' [https://business-science.github.io/timetk/](https://business-science.github.io/timetk/)
#'
"_PACKAGE"
#' @importFrom dplyr %>%
#' @importFrom xts xts
#' @import recipes
#' @importFrom generics tidy
NULL
